@@ -36,6 +36,8 @@ pub mod message;
 pub mod pact;
 pub mod sync_pact;
 pub mod message_pact;
+mod iterator_utils;
+pub mod plugins;
 
 /// A "prelude" or a default list of import types to include.
 pub mod prelude {
@@ -156,16 +158,29 @@ impl From<&String> for PactSpecification {
   }
 }
 
-impl ToString for PactSpecification {
-  fn to_string(&self) -> String {
+// impl ToString for PactSpecification {
+//   fn to_string(&self) -> String {
+//     match *self {
+//       PactSpecification::V1 => "V1",
+//       PactSpecification::V1_1 => "V1.1",
+//       PactSpecification::V2 => "V2",
+//       PactSpecification::V3 => "V3",
+//       PactSpecification::V4 => "V4",
+//       _ => "unknown"
+//     }.into()
+//   }
+// }
+
+impl Display for PactSpecification {
+  fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
     match *self {
-      PactSpecification::V1 => "V1",
-      PactSpecification::V1_1 => "V1.1",
-      PactSpecification::V2 => "V2",
-      PactSpecification::V3 => "V3",
-      PactSpecification::V4 => "V4",
-      _ => "unknown"
-    }.into()
+      PactSpecification::V1 => write!(f, "V1"),
+      PactSpecification::V1_1 => write!(f, "V1.1"),
+      PactSpecification::V2 => write!(f, "V2"),
+      PactSpecification::V3 => write!(f, "V3"),
+      PactSpecification::V4 => write!(f, "V4"),
+      _ => write!(f, "unknown")
+    }
   }
 }
 
@@ -186,7 +201,7 @@ impl Consumer {
       },
       None => "consumer".to_string()
     };
-    Consumer { name: val.clone() }
+    Consumer { name: val }
   }
 
   /// Converts this `Consumer` to a `Value` struct.
@@ -256,7 +271,7 @@ impl Provider {
       },
       None => "provider".to_string()
     };
-    Provider { name: val.clone() }
+    Provider { name: val }
   }
 
   /// Converts this `Provider` to a `Value` struct.
